==> ansible-10.0.0.tgz: lib/python3.11/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_system_log_ratelimit.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2024 Fortinet, Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_system_log_ratelimit
short_description: Logging rate limit.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.1.0"
author:
    - Xinwei Du (@dux-fortinet)
    - Xing Li (@lix-fortinet)
    - Jie Xue (@JieX19)
    - Link Zheng (@chillancezen)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
      Please change the arguments such as "var-name" to "var_name".
      Old argument names are still available yet you will receive deprecation warnings.
      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded
options:
    access_token:
        description: The token to access FortiManager without using username and password.
        type: str
    bypass_validation:
        description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
        type: bool
        default: false
    enable_log:
        description: Enable/Disable logging for task.
        type: bool
        default: false
    forticloud_access_token:
        description: Authenticate Ansible client with forticloud API access token.
        type: str
    proposed_method:
        description: The overridden method for the underlying Json RPC request.
        type: str
        choices:
          - update
          - set
          - add
    rc_succeeded:
        description: The rc codes list with which the conditions to succeed will be overriden.
        type: list
        elements: int
    rc_failed:
        description: The rc codes list with which the conditions to fail will be overriden.
        type: list
        elements: int
    workspace_locking_adom:
        description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
        type: str
    workspace_locking_timeout:
        description: The maximum time in seconds to wait for other user to release the workspace lock.
        type: int
        default: 300
    system_log_ratelimit:
        description: The top level parameters set.
        required: false
        type: dict
        suboptions:
            device:
                type: list
                elements: dict
                description: Device.
                suboptions:
                    device:
                        type: str
                        description: Device
                    filter-type:
                        type: str
                        description:
                            - Deprecated, please rename it to filter_type.
                            - Device filter type.
                            - devid - Device ID.
                        choices:
                            - 'devid'
                    id:
                        type: int
                        description: Device filter ID.
                    ratelimit:
                        type: int
                        description: Maximum device log rate limit.
            device-ratelimit-default:
                type: int
                description: Deprecated, please rename it to device_ratelimit_default. Default maximum device log rate limit.
            mode:
                type: str
                description:
                    - Logging rate limit mode.
                    - disable - Logging rate limit function disabled.
                    - manual - System rate limit and device rate limit both configurable, no limit if not configured.
                choices:
                    - 'disable'
                    - 'manual'
            system-ratelimit:
                type: int
                description: Deprecated, please rename it to system_ratelimit. Maximum system log rate limit.
            ratelimits:
                type: list
                elements: dict
                description: No description.
                suboptions:
                    filter:
                        type: str
                        description: Device or ADOM filter according to filter-type setting, wildcard expression supported.
                    filter-type:
                        type: str
                        description:
                            - Deprecated, please rename it to filter_type.
                            - Device filter type.
                            - devid - Device ID.
                            - adom - ADOM name.
                        choices:
                            - 'devid'
                            - 'adom'
                    id:
                        type: int
                        description: Filter ID.
                    ratelimit:
                        type: int
                        description: Maximum log rate limit.
'''

EXAMPLES = '''
- name: Example playbook (generated based on argument schema)
  hosts: fortimanagers
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Logging rate limit.
      fortinet.fortimanager.fmgr_system_log_ratelimit:
        # bypass_validation: false
        workspace_locking_adom: <value in [global, custom adom including root]>
        workspace_locking_timeout: 300
        # rc_succeeded: [0, -2, -3, ...]
        # rc_failed: [-2, -3, ...]
        system_log_ratelimit:
          device:
            -
              device: <string>
              filter_type: <value in [devid]>
              id: <integer>
              ratelimit: <integer>
          device_ratelimit_default: <integer>
          mode: <value in [disable, manual]>
          system_ratelimit: <integer>
          ratelimits:
            -
              filter: <string>
              filter_type: <value in [devid, adom]>
              id: <integer>
              ratelimit: <integer>
'''

RETURN = '''
meta:
    description: The result of the request.
    type: dict
    returned: always
    contains:
        request_url:
            description: The full url requested.
            returned: always
            type: str
            sample: /sys/login/user
        response_code:
            description: The status of api request.
            returned: always
            type: int
            sample: 0
        response_data:
            description: The api response.
            type: list
            returned: always
        response_message:
            description: The descriptive message of the api response.
            type: str
            returned: always
            sample: OK.
        system_information:
            description: The information of the target system.
            type: dict
            returned: always
rc:
    description: The status the request.
    type: int
    returned: always
    sample: 0
version_check_warning:
    description: Warning if the parameters used in the playbook are not supported by the current FortiManager version.
    type: list
    returned: complex
'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec


def main():
    jrpc_urls = [
        '/cli/global/system/log/ratelimit'
    ]

    perobject_jrpc_urls = [
        '/cli/global/system/log/ratelimit/{ratelimit}'
    ]

    url_params = []
    module_primary_key = None
    module_arg_spec = {
        'system_log_ratelimit': {
            'type': 'dict',
            'v_range': [['6.4.8', '']],
            'options': {
                'device': {
                    'v_range': [['6.4.8', '7.0.2']],
                    'type': 'list',
                    'options': {
                        'device': {'v_range': [['6.4.8', '7.0.2']], 'type': 'str'},
                        'filter-type': {'v_range': [['6.4.8', '7.0.2']], 'choices': ['devid'], 'type': 'str'},
                        'id': {'v_range': [['6.4.8', '7.0.2']], 'type': 'int'},
                        'ratelimit': {'v_range': [['6.4.8', '7.0.2']], 'type': 'int'}
                    },
                    'elements': 'dict'
                },
                'device-ratelimit-default': {'v_range': [['6.4.8', '']], 'type': 'int'},
                'mode': {'v_range': [['6.4.8', '']], 'choices': ['disable', 'manual'], 'type': 'str'},
                'system-ratelimit': {'v_range': [['6.4.8', '']], 'type': 'int'},
                'ratelimits': {
                    'v_range': [['7.0.3', '']],
                    'type': 'list',
                    'options': {
                        'filter': {'v_range': [['7.0.3', '']], 'type': 'str'},
                        'filter-type': {'v_range': [['7.0.3', '']], 'choices': ['devid', 'adom'], 'type': 'str'},
                        'id': {'v_range': [['7.0.3', '']], 'type': 'int'},
                        'ratelimit': {'v_range': [['7.0.3', '']], 'type': 'int'}
                    },
                    'elements': 'dict'
                }
            }

        }
    }

    module_option_spec = get_module_arg_spec('partial crud')
    module_arg_spec.update(module_option_spec)
    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_log_ratelimit'),
                           supports_check_mode=False)

    if not module._socket_path:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    connection = Connection(module._socket_path)
    connection.set_option('access_token', module.params.get('access_token', None))
    connection.set_option('enable_log', module.params.get('enable_log', False))
    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
    fmgr.validate_parameters(params_validation_blob)
    fmgr.process_partial_curd(argument_specs=module_arg_spec)

    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()

==> ansible-11.4.0.tgz: lib/python3.12/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_system_log_ratelimit.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2024 Fortinet, Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_system_log_ratelimit
short_description: Logging rate limit.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.1.0"
author:
    - Xinwei Du (@dux-fortinet)
    - Xing Li (@lix-fortinet)
    - Jie Xue (@JieX19)
    - Link Zheng (@chillancezen)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
      Please change the arguments such as "var-name" to "var_name".
      Old argument names are still available yet you will receive deprecation warnings.
      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded
options:
    access_token:
        description: The token to access FortiManager without using username and password.
        type: str
    bypass_validation:
        description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
        type: bool
        default: false
    enable_log:
        description: Enable/Disable logging for task.
        type: bool
        default: false
    forticloud_access_token:
        description: Authenticate Ansible client with forticloud API access token.
        type: str
    proposed_method:
        description: The overridden method for the underlying Json RPC request.
        type: str
        choices:
          - update
          - set
          - add
    rc_succeeded:
        description: The rc codes list with which the conditions to succeed will be overriden.
        type: list
        elements: int
    rc_failed:
        description: The rc codes list with which the conditions to fail will be overriden.
        type: list
        elements: int
    workspace_locking_adom:
        description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
        type: str
    workspace_locking_timeout:
        description: The maximum time in seconds to wait for other user to release the workspace lock.
        type: int
        default: 300
    system_log_ratelimit:
        description: The top level parameters set.
        required: false
        type: dict
        suboptions:
            device:
                type: list
                elements: dict
                description: Device.
                suboptions:
                    device:
                        type: str
                        description: Device
                    filter_type:
                        aliases: ['filter-type']
                        type: str
                        description:
                            - Device filter type.
                            - devid - Device ID.
                        choices:
                            - 'devid'
                    id:
                        type: int
                        description: Device filter ID.
                    ratelimit:
                        type: int
                        description: Maximum device log rate limit.
            device_ratelimit_default:
                aliases: ['device-ratelimit-default']
                type: int
                description: Default maximum device log rate limit.
            mode:
                type: str
                description:
                    - Logging rate limit mode.
                    - disable - Logging rate limit function disabled.
                    - manual - System rate limit and device rate limit both configurable, no limit if not configured.
                choices:
                    - 'disable'
                    - 'manual'
            system_ratelimit:
                aliases: ['system-ratelimit']
                type: int
                description: Maximum system log rate limit.
            ratelimits:
                type: list
                elements: dict
                description: Ratelimits.
                suboptions:
                    filter:
                        type: str
                        description: Device or ADOM filter according to filter-type setting, wildcard expression supported.
                    filter_type:
                        aliases: ['filter-type']
                        type: str
                        description:
                            - Device filter type.
                            - devid - Device ID.
                            - adom - ADOM name.
                        choices:
                            - 'devid'
                            - 'adom'
                    id:
                        type: int
                        description: Filter ID.
                    ratelimit:
                        type: int
                        description: Maximum log rate limit.
'''

EXAMPLES = '''
- name: Example playbook (generated based on argument schema)
  hosts: fortimanagers
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Logging rate limit.
      fortinet.fortimanager.fmgr_system_log_ratelimit:
        # bypass_validation: false
        workspace_locking_adom: <value in [global, custom adom including root]>
        workspace_locking_timeout: 300
        # rc_succeeded: [0, -2, -3, ...]
        # rc_failed: [-2, -3, ...]
        system_log_ratelimit:
          # device:
          #   - device: <string>
          #     filter_type: <value in [devid]>
          #     id: <integer>
          #     ratelimit: <integer>
          # device_ratelimit_default: <integer>
          # mode: <value in [disable, manual]>
          # system_ratelimit: <integer>
          # ratelimits:
          #   - filter: <string>
          #     filter_type: <value in [devid, adom]>
          #     id: <integer>
          #     ratelimit: <integer>
'''

RETURN = '''
meta:
    description: The result of the request.
    type: dict
    returned: always
    contains:
        request_url:
            description: The full url requested.
            returned: always
            type: str
            sample: /sys/login/user
        response_code:
            description: The status of api request.
            returned: always
            type: int
            sample: 0
        response_data:
            description: The api response.
            type: list
            returned: always
        response_message:
            description: The descriptive message of the api response.
            type: str
            returned: always
            sample: OK.
        system_information:
            description: The information of the target system.
            type: dict
            returned: always
rc:
    description: The status the request.
    type: int
    returned: always
    sample: 0
version_check_warning:
    description: Warning if the parameters used in the playbook are not supported by the current FortiManager version.
    type: list
    returned: complex
'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec


def main():
    urls_list = [
        '/cli/global/system/log/ratelimit'
    ]
    url_params = []
    module_primary_key = None
    module_arg_spec = {
        'system_log_ratelimit': {
            'type': 'dict',
            'v_range': [['6.4.8', '']],
            'options': {
                'device': {
                    'v_range': [['6.4.8', '7.0.2']],
                    'type': 'list',
                    'options': {
                        'device': {'v_range': [['6.4.8', '7.0.2']], 'type': 'str'},
                        'filter-type': {'v_range': [['6.4.8', '7.0.2']], 'choices': ['devid'], 'type': 'str'},
                        'id': {'v_range': [['6.4.8', '7.0.2']], 'type': 'int'},
                        'ratelimit': {'v_range': [['6.4.8', '7.0.2']], 'type': 'int'}
                    },
                    'elements': 'dict'
                },
                'device-ratelimit-default': {'v_range': [['6.4.8', '']], 'type': 'int'},
                'mode': {'v_range': [['6.4.8', '']], 'choices': ['disable', 'manual'], 'type': 'str'},
                'system-ratelimit': {'v_range': [['6.4.8', '']], 'type': 'int'},
                'ratelimits': {
                    'v_range': [['7.0.3', '']],
                    'type': 'list',
                    'options': {
                        'filter': {'v_range': [['7.0.3', '']], 'type': 'str'},
                        'filter-type': {'v_range': [['7.0.3', '']], 'choices': ['devid', 'adom'], 'type': 'str'},
                        'id': {'v_range': [['7.0.3', '']], 'type': 'int'},
                        'ratelimit': {'v_range': [['7.0.3', '']], 'type': 'int'}
                    },
                    'elements': 'dict'
                }
            }
        }
    }

    module_option_spec = get_module_arg_spec('partial crud')
    module_arg_spec.update(module_option_spec)
    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_log_ratelimit'),
                           supports_check_mode=True)

    if not module._socket_path:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    connection = Connection(module._socket_path)
    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
                       module, connection, top_level_schema_name='data')
    fmgr.validate_parameters(params_validation_blob)
    fmgr.process_partial_crud()

    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()
